@@ -51,12 +51,12 @@ Agent <- R6::R6Class(
 #' @param event an object of the R6 class Event, or an external pointer 
 #' returned by newEvent
 #' 
-#' @return the agent itself
+#' @return the agent itself (invisible)
     schedule = function(event) {
       if (inherits(event, "R6Event"))
         event = event$get
       schedule(private$agent, event)
-      return(self)
+      invisible(self)
     },
 
 #' Unschedule an event
@@ -64,12 +64,12 @@ Agent <- R6::R6Class(
 #' @param event an object of the R6 class Event, or an external pointer 
 #' returned by newEvent
 #' 
-#' @return the agent itself
+#' @return the agent itself (invisible)
     unschedule = function(event) {
       if (inherits(event, "R6Event"))
         event = event$get
       unschedule(private$agent, event)
-      return(self)
+      invisible(self)
     },
 
 #' leave the population that the agent is in
@@ -77,20 +77,20 @@ Agent <- R6::R6Class(
 #' @return the agent itself
     leave = function() {
       leave(private$agent)
-      return(self)
+      invisible(self)
     },
 
 #' set the time of death for the agent
 #' 
 #' @param time the time of death, a numeric value
 #' 
-#' @return the agent itself
+#' @return the agent itself (invisible)
 #' 
 #' @details At the time of death, the agent is removed from the simulation. 
 #' Calling it multiple times causes the agent to die at the earliest time.
     setDeathTime = function(time) {
       setDeathTime(private$agent, time)
-      self
+      invisible(self)
     }
   ),
   private = list(
@@ -176,8 +176,6 @@ NULL
 #' @param state an R list giving the components of the state to be
 #' undated.
 #' 
-#' @return the agent itself
-#' 
 #' @details In this framework, a state is a list, each named
 #' component is called a domain. This function only updates the 
 #' values of the domain given in the "value" list, while leave the
@@ -234,8 +232,6 @@ matchState = function(agent, rule) {
 #' 
 #' @param event an external pointer returned by newEvent
 #' 
-#' @return the agent itself
-#' 
 #' @details If agent is an R6 object, then we should use either 
 #' agent$schedule(event) or schedule(agent$get, event)
 #' 
@@ -253,8 +249,6 @@ NULL
 #' 
 #' @param event an external pointer returned by newEvent
 #' 
-#' @return the agent itself
-#' 
 #' @details If agent is an R6 object, then we should use either 
 #' agent$unschedule(event) or unschedule(agent$get, event)
 #' 
@@ -270,8 +264,6 @@ NULL
 #' 
 #' @param agent an external pointer returned by newAgent
 #' 
-#' @return the agent itself
-#' 
 #' @details If agent is an R6 object, then we should use either
 #' agent$clearEvents() or clearEvents(agent$get)
 #' 
@@ -284,8 +276,6 @@ NULL
 #' 
 #' @param agent an external pointer returned by newAgent
 #' 
-#' @return the agent itself
-#' 
 #' @details If agent is an R6 object, then we should use either
 #' agent$leave() or leave(agent$get)
 #' 
@@ -300,8 +290,6 @@ NULL
 #' 
 #' @param time the time of death, a numeric value
 #' 
-#' @return the agent itself
-#' 
 #' @details If agent is an R6 object, then we should use either
 #' agent$leave() or leave(agent$get)
 #' 
